from ..interactive_tree import interactive_tree
from ..tools.cli_tools import *
from ..tools.click_wrappers import WrapperGroup

#####
# settings
#####
@interactive_tree.group("settings", help="manage your settings", cls=WrapperGroup)
def settings_tree():
	pass

#####
# settings identity
#####
@settings_tree.group("identity", help="manage identity settings", cls=WrapperGroup)
def settings_identity_tree():
	pass


#####
# settings identity invitation
#####
@settings_identity_tree.group("invitation")
def settings_identity_invitation_tree():
	pass


#####
# settings identity invitation get
#####
@settings_identity_invitation_tree.command("get")
@click.option("-f", "--fields", "fields", type=str)
async def identity_settings_invitation_get(fields: str):
	settings = await ClientSingleton.get_client().settings_identity_get()
	if fields:
		filter_fields_and_print_normal_message(settings.invitation, fields)
	else:
		print_normal_message(settings_invitation_to_string(settings.invitation), settings.invitation)

#####
# settings identity invitation set
#####
@settings_identity_invitation_tree.command("set")
@click.option("-a", "--all", "all_opt", is_flag=True)
@click.option("-n", "--none", "none_opt", is_flag=True)
@click.option("-i", "--invitation", "invitation", is_flag=True)
@click.option("-t", "--introduction", "introduction", is_flag=True)
@click.option("-o", "--one-to-one", "one_to_one", is_flag=True)
@click.option("-g", "--group", "group", is_flag=True)
async def identity_settings_invitation_set(all_opt: bool, none_opt: bool, invitation: bool, introduction: bool, one_to_one: bool, group: bool):
	identity_settings: datatypes.IdentitySettings = await ClientSingleton.get_client().settings_identity_get()

	if all_opt:
		invitation: datatypes.IdentitySettings.AutoAcceptInvitation = datatypes.IdentitySettings.AutoAcceptInvitation(
			auto_accept_invitation=True,
			auto_accept_introduction=True,
			auto_accept_one_to_one=True,
			auto_accept_group=True
		)
	elif none_opt:
		invitation: datatypes.IdentitySettings.AutoAcceptInvitation = datatypes.IdentitySettings.AutoAcceptInvitation()
	elif invitation or introduction or one_to_one or group:
		invitation: datatypes.IdentitySettings.AutoAcceptInvitation = datatypes.IdentitySettings.AutoAcceptInvitation(
			auto_accept_invitation=invitation,
			auto_accept_introduction=introduction,
			auto_accept_one_to_one=one_to_one,
			auto_accept_group=group
		)
	else:
		raise click.UsageError("Specify at least one option")

	identity_settings.invitation = invitation

	new_settings = await ClientSingleton.get_client().settings_identity_set(identity_settings=identity_settings)
	print_normal_message(settings_invitation_to_string(new_settings.invitation), new_settings.invitation)

#####
# settings identity keycloak
#####
@settings_identity_tree.group("keycloak")
def settings_identity_keycloak_tree():
	pass


#####
# settings identity keycloak get
#####
@settings_identity_keycloak_tree.command("get")
@click.option("-f", "--fields", "fields", type=str)
async def identity_settings_keycloak_get(fields: str):
	settings = await ClientSingleton.get_client().settings_identity_get()
	if fields:
		filter_fields_and_print_normal_message(settings.keycloak, fields)
	else:
		print_normal_message(settings_keycloak_to_string(settings.keycloak), settings.keycloak)

#####
# settings identity keycloak set
#####
@settings_identity_keycloak_tree.command("set")
@click.option("--auto-invite", "auto_invite", is_flag=True)
async def identity_settings_keycloak_set(auto_invite: bool):
	identity_settings: datatypes.IdentitySettings = await ClientSingleton.get_client().settings_identity_get()

	keycloak: datatypes.IdentitySettings.Keycloak = datatypes.IdentitySettings.Keycloak(
		auto_invite_new_members=auto_invite
	)
	identity_settings.keycloak = keycloak

	new_settings = await ClientSingleton.get_client().settings_identity_set(identity_settings=identity_settings)
	print_normal_message(settings_keycloak_to_string(new_settings.keycloak), new_settings.keycloak)

#####
# settings identity message
#####
@settings_identity_tree.group("message")
def settings_identity_message_tree():
	pass


#####
# settings identity message get
#####
@settings_identity_message_tree.command("get")
@click.option("-f", "--fields", "fields", type=str)
async def identity_settings_message_get(fields: str):
	settings = await ClientSingleton.get_client().settings_identity_get()
	if fields:
		filter_fields_and_print_normal_message(settings.message_retention, fields)
	else:
		print_normal_message(settings_message_to_string(settings.message_retention), settings.message_retention)

#####
# settings identity message set
#####
@settings_identity_message_tree.command("set")
@click.option("-d", "--discussion-count", "discussion_count", help="Set a maximum number of messages to keep in each discussion", type=click.INT, default=0)
@click.option("-g", "--global-count", "global_count", help="Set a maximum number of messages to keep globally", type=click.INT, default=0)
@click.option("-t", "--duration", help="Set a duration after messages are deleted (in seconds)", type=click.INT, default=0)
@click.option("-l", "--locked", help="Delete message in locked discussions", is_flag=True)
@click.option("-p", "--preserve-location", help="Do not delete non-finished location sharing messages", is_flag=True)
@click.option("-n", "--none", "none_opt", is_flag=True)
async def identity_settings_message_set(discussion_count: int, global_count: int, duration: int, locked: bool, preserve_location: bool, none_opt: bool):
	if discussion_count or global_count or duration or locked or preserve_location:
		message_retention: datatypes.IdentitySettings.MessageRetention = datatypes.IdentitySettings.MessageRetention(
			existence_duration=duration,
			discussion_count=discussion_count,
			global_count=global_count,
			clean_locked_discussions=locked,
			preserve_is_sharing_location_messages=preserve_location
		)
	elif none_opt:
		message_retention: datatypes.IdentitySettings.MessageRetention = datatypes.IdentitySettings.MessageRetention()
	else:
		raise click.UsageError("Specify at least one option")

	identity_settings: datatypes.IdentitySettings = await ClientSingleton.get_client().settings_identity_get()
	identity_settings.message_retention = message_retention

	new_settings = await ClientSingleton.get_client().settings_identity_set(identity_settings=identity_settings)
	print_normal_message(settings_message_to_string(new_settings.message_retention), new_settings.message_retention)


#####
# settings discussion
#####
@settings_tree.group("discussion", help="manage discussion settings", cls=WrapperGroup)
def settings_discussion_tree():
	pass


#####
# settings discussion get
#####
@settings_discussion_tree.command("get")
@click.argument("discussion_id", nargs=1, type=click.INT, required=True)
@click.option("-f", "--fields", "fields", type=str)
async def discussion_settings_get(discussion_id: int, fields: str):
	settings = await ClientSingleton.get_client().settings_discussion_get(discussion_id=discussion_id)
	filter_fields_and_print_normal_message(settings, fields)


#####
# settings discussion set
#####
@settings_discussion_tree.command("set")
@click.option("-o", "--once", "read_once", is_flag=True)
@click.option("-e", "--existence", "existence_duration", type=click.INT, default=0)
@click.option("-v", "--visibility", "visibility_duration", type=click.INT, default=0)
@click.argument("discussion_id", nargs=1, type=click.INT)
async def discussion_settings_set(discussion_id: int, read_once: bool, existence_duration: int,
									visibility_duration: int):
	settings = datatypes.DiscussionSettings(discussion_id=discussion_id,
											read_once=read_once,
											existence_duration=existence_duration,
											visibility_duration=visibility_duration)
	new_settings = await ClientSingleton.get_client().settings_discussion_set(discussion_settings=settings)
	print_normal_message(new_settings, new_settings)

def settings_invitation_to_string(invitation: datatypes.IdentitySettings.AutoAcceptInvitation):
	return f"""
auto_accept_invitation: {invitation.auto_accept_invitation}
auto_accept_introduction: {invitation.auto_accept_introduction}
auto_accept_group: {invitation.auto_accept_group}
auto_accept_one_to_one: {invitation.auto_accept_one_to_one}
""".strip()

def settings_keycloak_to_string(keycloak: datatypes.IdentitySettings.Keycloak):
	return f"""
auto_invite_new_members: {keycloak.auto_invite_new_members}
""".strip()

def settings_message_to_string(message: datatypes.IdentitySettings.MessageRetention):
	return f"""
discussion_count: {message.discussion_count}
global_count: {message.global_count}
existence_duration: {message.existence_duration}
clean_locked_discussions: {message.clean_locked_discussions}
preserve_is_sharing_location_messages: {message.preserve_is_sharing_location_messages}
""".strip()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/notification/v1/group_notifications.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/notification/v1/group_notifications.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import group_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6olvid/daemon/notification/v1/group_notifications.proto\x12\x1colvid.daemon.notification.v1\x1a%olvid/daemon/datatypes/v1/group.proto\"\xa7\x01\n\x1fSubscribeToGroupNewNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12N\n\x0cgroup_filter\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"N\n\x14GroupNewNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xc8\x01\n#SubscribeToGroupDeletedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"R\n\x18GroupDeletedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\x9c\x02\n\'SubscribeToGroupNameUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x35\n\x14previous_name_search\x18\x04 \x01(\tH\x02R\x12previousNameSearch\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x17\n\x15_previous_name_search\"{\n\x1cGroupNameUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12#\n\rprevious_name\x18\x02 \x01(\tR\x0cpreviousName\"\xcd\x01\n(SubscribeToGroupPhotoUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filter\"W\n\x1dGroupPhotoUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\"\xb8\x02\n.SubscribeToGroupDescriptionUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x43\n\x1bprevious_description_search\x18\x04 \x01(\tH\x02R\x19previousDescriptionSearch\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x1e\n\x1c_previous_description_search\"\x90\x01\n#GroupDescriptionUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12\x31\n\x14previous_description\x18\x02 \x01(\tR\x13previousDescription\"\xdb\x02\n.SubscribeToGroupPendingMemberAddedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12l\n\x15pending_member_filter\x18\x04 \x01(\x0b\x32\x33.olvid.daemon.datatypes.v1.PendingGroupMemberFilterH\x02R\x13pendingMemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x18\n\x16_pending_member_filter\"\xb3\x01\n#GroupPendingMemberAddedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"\xdd\x02\n0SubscribeToGroupPendingMemberRemovedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12l\n\x15pending_member_filter\x18\x04 \x01(\x0b\x32\x33.olvid.daemon.datatypes.v1.PendingGroupMemberFilterH\x02R\x13pendingMemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x18\n\x16_pending_member_filter\"\xb5\x01\n%GroupPendingMemberRemovedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12T\n\x0epending_member\x18\x02 \x01(\x0b\x32-.olvid.daemon.datatypes.v1.PendingGroupMemberR\rpendingMember\"\xb7\x02\n(SubscribeToGroupMemberJoinedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filter\"\x97\x01\n\x1dGroupMemberJoinedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"\xb5\x02\n&SubscribeToGroupMemberLeftNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filter\"\x95\x01\n\x1bGroupMemberLeftNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\"\xea\x03\n1SubscribeToGroupOwnPermissionsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12\x64\n\x12permissions_filter\x18\x04 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x02R\x11permissionsFilter\x88\x01\x01\x12u\n\x1bprevious_permissions_filter\x18\x05 \x01(\x0b\x32\x30.olvid.daemon.datatypes.v1.GroupPermissionFilterH\x03R\x19previousPermissionsFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x15\n\x13_permissions_filterB\x1e\n\x1c_previous_permissions_filter\"\x9b\x02\n&GroupOwnPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12S\n\x0bpermissions\x18\x02 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x0bpermissions\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissions\"\xd3\x03\n4SubscribeToGroupMemberPermissionsUpdatedNotification\x12\x19\n\x05\x63ount\x18\x01 \x01(\x04H\x00R\x05\x63ount\x88\x01\x01\x12\x1b\n\tgroup_ids\x18\x02 \x03(\x04R\x08groupIds\x12N\n\x0cgroup_filter\x18\x03 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupFilterH\x01R\x0bgroupFilter\x88\x01\x01\x12V\n\rmember_filter\x18\x04 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x02R\x0cmemberFilter\x88\x01\x01\x12o\n\x1aprevious_permission_filter\x18\x05 \x01(\x0b\x32,.olvid.daemon.datatypes.v1.GroupMemberFilterH\x03R\x18previousPermissionFilter\x88\x01\x01\x42\x08\n\x06_countB\x0f\n\r_group_filterB\x10\n\x0e_member_filterB\x1d\n\x1b_previous_permission_filter\"\x89\x02\n)GroupMemberPermissionsUpdatedNotification\x12\x36\n\x05group\x18\x01 \x01(\x0b\x32 .olvid.daemon.datatypes.v1.GroupR\x05group\x12>\n\x06member\x18\x02 \x01(\x0b\x32&.olvid.daemon.datatypes.v1.GroupMemberR\x06member\x12\x64\n\x14previous_permissions\x18\x03 \x01(\x0b\x32\x31.olvid.daemon.datatypes.v1.GroupMemberPermissionsR\x13previousPermissionsB\xdf\x01\n com.olvid.daemon.notification.v1B\x17GroupNotificationsProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODN\xaa\x02\x1cOlvid.Daemon.Notification.V1\xca\x02\x1cOlvid\\Daemon\\Notification\\V1\xe2\x02(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\xea\x02\x1fOlvid::Daemon::Notification::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.notification.v1.group_notifications_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n com.olvid.daemon.notification.v1B\027GroupNotificationsProtoP\001Z\017olvid.io/daemon\242\002\003ODN\252\002\034Olvid.Daemon.Notification.V1\312\002\034Olvid\\Daemon\\Notification\\V1\342\002(Olvid\\Daemon\\Notification\\V1\\GPBMetadata\352\002\037Olvid::Daemon::Notification::V1'
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_start=128
  _globals['_SUBSCRIBETOGROUPNEWNOTIFICATION']._serialized_end=295
  _globals['_GROUPNEWNOTIFICATION']._serialized_start=297
  _globals['_GROUPNEWNOTIFICATION']._serialized_end=375
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_start=378
  _globals['_SUBSCRIBETOGROUPDELETEDNOTIFICATION']._serialized_end=578
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_start=580
  _globals['_GROUPDELETEDNOTIFICATION']._serialized_end=662
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_start=665
  _globals['_SUBSCRIBETOGROUPNAMEUPDATEDNOTIFICATION']._serialized_end=949
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_start=951
  _globals['_GROUPNAMEUPDATEDNOTIFICATION']._serialized_end=1074
  _globals['_SUBSCRIBETOGROUPPHOTOUPDATEDNOTIFICATION']._serialized_start=1077
  _globals['_SUBSCRIBETOGROUPPHOTOUPDATEDNOTIFICATION']._serialized_end=1282
  _globals['_GROUPPHOTOUPDATEDNOTIFICATION']._serialized_start=1284
  _globals['_GROUPPHOTOUPDATEDNOTIFICATION']._serialized_end=1371
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=1374
  _globals['_SUBSCRIBETOGROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=1686
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_start=1689
  _globals['_GROUPDESCRIPTIONUPDATEDNOTIFICATION']._serialized_end=1833
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=1836
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=2183
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_start=2186
  _globals['_GROUPPENDINGMEMBERADDEDNOTIFICATION']._serialized_end=2365
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=2368
  _globals['_SUBSCRIBETOGROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=2717
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_start=2720
  _globals['_GROUPPENDINGMEMBERREMOVEDNOTIFICATION']._serialized_end=2901
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_start=2904
  _globals['_SUBSCRIBETOGROUPMEMBERJOINEDNOTIFICATION']._serialized_end=3215
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_start=3218
  _globals['_GROUPMEMBERJOINEDNOTIFICATION']._serialized_end=3369
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_start=3372
  _globals['_SUBSCRIBETOGROUPMEMBERLEFTNOTIFICATION']._serialized_end=3681
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_start=3684
  _globals['_GROUPMEMBERLEFTNOTIFICATION']._serialized_end=3833
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=3836
  _globals['_SUBSCRIBETOGROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=4326
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=4329
  _globals['_GROUPOWNPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=4612
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=4615
  _globals['_SUBSCRIBETOGROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=5082
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_start=5085
  _globals['_GROUPMEMBERPERMISSIONSUPDATEDNOTIFICATION']._serialized_end=5350
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from .....olvid.daemon.notification.v1 import attachment_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2
from .....olvid.daemon.notification.v1 import call_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2
from .....olvid.daemon.notification.v1 import contact_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2
from .....olvid.daemon.notification.v1 import discussion_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2
from .....olvid.daemon.notification.v1 import group_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2
from .....olvid.daemon.notification.v1 import invitation_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2
from .....olvid.daemon.notification.v1 import message_notifications_pb2 as olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2


class InvitationNotificationServiceStub(object):
    """must be for admin only
    // Identity
    service IdentityNotificationService {
    	rpc IdentityCreated(notification.v1.SubscribeToIdentityCreatedNotification) returns (stream notification.v1.IdentityCreatedNotification) {}
    	rpc IdentityDeleted(notification.v1.SubscribeToIdentityDeletedNotification) returns (stream notification.v1.IdentityDeletedNotification) {}
    	rpc IdentityDetailsUpdated(notification.v1.SubscribeToIdentityDetailsUpdatedNotification) returns (stream notification.v1.IdentityDetailsUpdatedNotification) {}
    }

    Invitation
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.InvitationReceived = channel.unary_stream(
                '/olvid.daemon.services.v1.InvitationNotificationService/InvitationReceived',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationReceivedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationReceivedNotification.FromString,
                _registered_method=True)
        self.InvitationSent = channel.unary_stream(
                '/olvid.daemon.services.v1.InvitationNotificationService/InvitationSent',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationSentNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationSentNotification.FromString,
                _registered_method=True)
        self.InvitationDeleted = channel.unary_stream(
                '/olvid.daemon.services.v1.InvitationNotificationService/InvitationDeleted',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationDeletedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationDeletedNotification.FromString,
                _registered_method=True)
        self.InvitationUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.InvitationNotificationService/InvitationUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationUpdatedNotification.FromString,
                _registered_method=True)


class InvitationNotificationServiceServicer(object):
    """must be for admin only
    // Identity
    service IdentityNotificationService {
    	rpc IdentityCreated(notification.v1.SubscribeToIdentityCreatedNotification) returns (stream notification.v1.IdentityCreatedNotification) {}
    	rpc IdentityDeleted(notification.v1.SubscribeToIdentityDeletedNotification) returns (stream notification.v1.IdentityDeletedNotification) {}
    	rpc IdentityDetailsUpdated(notification.v1.SubscribeToIdentityDetailsUpdatedNotification) returns (stream notification.v1.IdentityDetailsUpdatedNotification) {}
    }

    Invitation
    """

    def InvitationReceived(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvitationSent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvitationDeleted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InvitationUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InvitationNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'InvitationReceived': grpc.unary_stream_rpc_method_handler(
                    servicer.InvitationReceived,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationReceivedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationReceivedNotification.SerializeToString,
            ),
            'InvitationSent': grpc.unary_stream_rpc_method_handler(
                    servicer.InvitationSent,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationSentNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationSentNotification.SerializeToString,
            ),
            'InvitationDeleted': grpc.unary_stream_rpc_method_handler(
                    servicer.InvitationDeleted,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationDeletedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationDeletedNotification.SerializeToString,
            ),
            'InvitationUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.InvitationUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationUpdatedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.InvitationNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.InvitationNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class InvitationNotificationService(object):
    """must be for admin only
    // Identity
    service IdentityNotificationService {
    	rpc IdentityCreated(notification.v1.SubscribeToIdentityCreatedNotification) returns (stream notification.v1.IdentityCreatedNotification) {}
    	rpc IdentityDeleted(notification.v1.SubscribeToIdentityDeletedNotification) returns (stream notification.v1.IdentityDeletedNotification) {}
    	rpc IdentityDetailsUpdated(notification.v1.SubscribeToIdentityDetailsUpdatedNotification) returns (stream notification.v1.IdentityDetailsUpdatedNotification) {}
    }

    Invitation
    """

    @staticmethod
    def InvitationReceived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.InvitationNotificationService/InvitationReceived',
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationReceivedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationReceivedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InvitationSent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.InvitationNotificationService/InvitationSent',
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationSentNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationSentNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InvitationDeleted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.InvitationNotificationService/InvitationDeleted',
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationDeletedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationDeletedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def InvitationUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.InvitationNotificationService/InvitationUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.SubscribeToInvitationUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_invitation__notifications__pb2.InvitationUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class ContactNotificationServiceStub(object):
    """Contact
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ContactNew = channel.unary_stream(
                '/olvid.daemon.services.v1.ContactNotificationService/ContactNew',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactNewNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactNewNotification.FromString,
                _registered_method=True)
        self.ContactDeleted = channel.unary_stream(
                '/olvid.daemon.services.v1.ContactNotificationService/ContactDeleted',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDeletedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDeletedNotification.FromString,
                _registered_method=True)
        self.ContactDetailsUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.ContactNotificationService/ContactDetailsUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDetailsUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDetailsUpdatedNotification.FromString,
                _registered_method=True)
        self.ContactPhotoUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.ContactNotificationService/ContactPhotoUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactPhotoUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactPhotoUpdatedNotification.FromString,
                _registered_method=True)


class ContactNotificationServiceServicer(object):
    """Contact
    """

    def ContactNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContactDeleted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContactDetailsUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ContactPhotoUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ContactNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ContactNew': grpc.unary_stream_rpc_method_handler(
                    servicer.ContactNew,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactNewNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactNewNotification.SerializeToString,
            ),
            'ContactDeleted': grpc.unary_stream_rpc_method_handler(
                    servicer.ContactDeleted,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDeletedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDeletedNotification.SerializeToString,
            ),
            'ContactDetailsUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.ContactDetailsUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDetailsUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDetailsUpdatedNotification.SerializeToString,
            ),
            'ContactPhotoUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.ContactPhotoUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactPhotoUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactPhotoUpdatedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.ContactNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.ContactNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ContactNotificationService(object):
    """Contact
    """

    @staticmethod
    def ContactNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.ContactNotificationService/ContactNew',
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactNewNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactNewNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ContactDeleted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.ContactNotificationService/ContactDeleted',
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDeletedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDeletedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ContactDetailsUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.ContactNotificationService/ContactDetailsUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactDetailsUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactDetailsUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ContactPhotoUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.ContactNotificationService/ContactPhotoUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.SubscribeToContactPhotoUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_contact__notifications__pb2.ContactPhotoUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class GroupNotificationServiceStub(object):
    """Group
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.GroupNew = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupNew',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNewNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNewNotification.FromString,
                _registered_method=True)
        self.GroupDeleted = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupDeleted',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDeletedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDeletedNotification.FromString,
                _registered_method=True)
        self.GroupNameUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupNameUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNameUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNameUpdatedNotification.FromString,
                _registered_method=True)
        self.GroupPhotoUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupPhotoUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPhotoUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPhotoUpdatedNotification.FromString,
                _registered_method=True)
        self.GroupDescriptionUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupDescriptionUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDescriptionUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDescriptionUpdatedNotification.FromString,
                _registered_method=True)
        self.GroupPendingMemberAdded = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupPendingMemberAdded',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberAddedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberAddedNotification.FromString,
                _registered_method=True)
        self.GroupPendingMemberRemoved = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupPendingMemberRemoved',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberRemovedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberRemovedNotification.FromString,
                _registered_method=True)
        self.GroupMemberJoined = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberJoined',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberJoinedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberJoinedNotification.FromString,
                _registered_method=True)
        self.GroupMemberLeft = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberLeft',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberLeftNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberLeftNotification.FromString,
                _registered_method=True)
        self.GroupOwnPermissionsUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupOwnPermissionsUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupOwnPermissionsUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupOwnPermissionsUpdatedNotification.FromString,
                _registered_method=True)
        self.GroupMemberPermissionsUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberPermissionsUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberPermissionsUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberPermissionsUpdatedNotification.FromString,
                _registered_method=True)


class GroupNotificationServiceServicer(object):
    """Group
    """

    def GroupNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupDeleted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupNameUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPhotoUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupDescriptionUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPendingMemberAdded(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupPendingMemberRemoved(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupMemberJoined(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupMemberLeft(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupOwnPermissionsUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GroupMemberPermissionsUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_GroupNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'GroupNew': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupNew,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNewNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNewNotification.SerializeToString,
            ),
            'GroupDeleted': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupDeleted,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDeletedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDeletedNotification.SerializeToString,
            ),
            'GroupNameUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupNameUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNameUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNameUpdatedNotification.SerializeToString,
            ),
            'GroupPhotoUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupPhotoUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPhotoUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPhotoUpdatedNotification.SerializeToString,
            ),
            'GroupDescriptionUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupDescriptionUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDescriptionUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDescriptionUpdatedNotification.SerializeToString,
            ),
            'GroupPendingMemberAdded': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupPendingMemberAdded,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberAddedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberAddedNotification.SerializeToString,
            ),
            'GroupPendingMemberRemoved': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupPendingMemberRemoved,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberRemovedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberRemovedNotification.SerializeToString,
            ),
            'GroupMemberJoined': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupMemberJoined,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberJoinedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberJoinedNotification.SerializeToString,
            ),
            'GroupMemberLeft': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupMemberLeft,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberLeftNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberLeftNotification.SerializeToString,
            ),
            'GroupOwnPermissionsUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupOwnPermissionsUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupOwnPermissionsUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupOwnPermissionsUpdatedNotification.SerializeToString,
            ),
            'GroupMemberPermissionsUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.GroupMemberPermissionsUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberPermissionsUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberPermissionsUpdatedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.GroupNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.GroupNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class GroupNotificationService(object):
    """Group
    """

    @staticmethod
    def GroupNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupNew',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNewNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNewNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupDeleted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupDeleted',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDeletedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDeletedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupNameUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupNameUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupNameUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupNameUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPhotoUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupPhotoUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPhotoUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPhotoUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupDescriptionUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupDescriptionUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupDescriptionUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupDescriptionUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPendingMemberAdded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupPendingMemberAdded',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberAddedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberAddedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupPendingMemberRemoved(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupPendingMemberRemoved',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupPendingMemberRemovedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupPendingMemberRemovedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupMemberJoined(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberJoined',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberJoinedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberJoinedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupMemberLeft(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberLeft',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberLeftNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberLeftNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupOwnPermissionsUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupOwnPermissionsUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupOwnPermissionsUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupOwnPermissionsUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GroupMemberPermissionsUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.GroupNotificationService/GroupMemberPermissionsUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.SubscribeToGroupMemberPermissionsUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_group__notifications__pb2.GroupMemberPermissionsUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class DiscussionNotificationServiceStub(object):
    """Discussion
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.DiscussionNew = channel.unary_stream(
                '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionNew',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionNewNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionNewNotification.FromString,
                _registered_method=True)
        self.DiscussionLocked = channel.unary_stream(
                '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionLocked',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionLockedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionLockedNotification.FromString,
                _registered_method=True)
        self.DiscussionTitleUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionTitleUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionTitleUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionTitleUpdatedNotification.FromString,
                _registered_method=True)
        self.DiscussionSettingsUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionSettingsUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionSettingsUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionSettingsUpdatedNotification.FromString,
                _registered_method=True)


class DiscussionNotificationServiceServicer(object):
    """Discussion
    """

    def DiscussionNew(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiscussionLocked(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiscussionTitleUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DiscussionSettingsUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DiscussionNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'DiscussionNew': grpc.unary_stream_rpc_method_handler(
                    servicer.DiscussionNew,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionNewNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionNewNotification.SerializeToString,
            ),
            'DiscussionLocked': grpc.unary_stream_rpc_method_handler(
                    servicer.DiscussionLocked,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionLockedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionLockedNotification.SerializeToString,
            ),
            'DiscussionTitleUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.DiscussionTitleUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionTitleUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionTitleUpdatedNotification.SerializeToString,
            ),
            'DiscussionSettingsUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.DiscussionSettingsUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionSettingsUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionSettingsUpdatedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.DiscussionNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.DiscussionNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DiscussionNotificationService(object):
    """Discussion
    """

    @staticmethod
    def DiscussionNew(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionNew',
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionNewNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionNewNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DiscussionLocked(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionLocked',
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionLockedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionLockedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DiscussionTitleUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionTitleUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionTitleUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionTitleUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DiscussionSettingsUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.DiscussionNotificationService/DiscussionSettingsUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.SubscribeToDiscussionSettingsUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_discussion__notifications__pb2.DiscussionSettingsUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class MessageNotificationServiceStub(object):
    """Message
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.MessageReceived = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageReceived',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReceivedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReceivedNotification.FromString,
                _registered_method=True)
        self.MessageSent = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageSent',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageSentNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageSentNotification.FromString,
                _registered_method=True)
        self.MessageDeleted = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageDeleted',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeletedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeletedNotification.FromString,
                _registered_method=True)
        self.MessageBodyUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageBodyUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageBodyUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageBodyUpdatedNotification.FromString,
                _registered_method=True)
        self.MessageUploaded = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageUploaded',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageUploadedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageUploadedNotification.FromString,
                _registered_method=True)
        self.MessageDelivered = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageDelivered',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeliveredNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeliveredNotification.FromString,
                _registered_method=True)
        self.MessageRead = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageRead',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReadNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReadNotification.FromString,
                _registered_method=True)
        self.MessageLocationReceived = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationReceived',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationReceivedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationReceivedNotification.FromString,
                _registered_method=True)
        self.MessageLocationSent = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSent',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSentNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSentNotification.FromString,
                _registered_method=True)
        self.MessageLocationSharingStart = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingStart',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingStartNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingStartNotification.FromString,
                _registered_method=True)
        self.MessageLocationSharingUpdate = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingUpdate',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingUpdateNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingUpdateNotification.FromString,
                _registered_method=True)
        self.MessageLocationSharingEnd = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingEnd',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingEndNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingEndNotification.FromString,
                _registered_method=True)
        self.MessageReactionAdded = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionAdded',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionAddedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionAddedNotification.FromString,
                _registered_method=True)
        self.MessageReactionUpdated = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionUpdated',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionUpdatedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionUpdatedNotification.FromString,
                _registered_method=True)
        self.MessageReactionRemoved = channel.unary_stream(
                '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionRemoved',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionRemovedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionRemovedNotification.FromString,
                _registered_method=True)


class MessageNotificationServiceServicer(object):
    """Message
    """

    def MessageReceived(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageSent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageDeleted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageBodyUpdated(self, request, context):
        """datatypes.v1.Message updates
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageUploaded(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageDelivered(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageLocationReceived(self, request, context):
        """location message
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageLocationSent(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageLocationSharingStart(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageLocationSharingUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageLocationSharingEnd(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageReactionAdded(self, request, context):
        """datatypes.v1.Message reactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageReactionUpdated(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageReactionRemoved(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MessageNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'MessageReceived': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageReceived,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReceivedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReceivedNotification.SerializeToString,
            ),
            'MessageSent': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageSent,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageSentNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageSentNotification.SerializeToString,
            ),
            'MessageDeleted': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageDeleted,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeletedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeletedNotification.SerializeToString,
            ),
            'MessageBodyUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageBodyUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageBodyUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageBodyUpdatedNotification.SerializeToString,
            ),
            'MessageUploaded': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageUploaded,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageUploadedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageUploadedNotification.SerializeToString,
            ),
            'MessageDelivered': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageDelivered,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeliveredNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeliveredNotification.SerializeToString,
            ),
            'MessageRead': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageRead,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReadNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReadNotification.SerializeToString,
            ),
            'MessageLocationReceived': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageLocationReceived,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationReceivedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationReceivedNotification.SerializeToString,
            ),
            'MessageLocationSent': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageLocationSent,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSentNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSentNotification.SerializeToString,
            ),
            'MessageLocationSharingStart': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageLocationSharingStart,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingStartNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingStartNotification.SerializeToString,
            ),
            'MessageLocationSharingUpdate': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageLocationSharingUpdate,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingUpdateNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingUpdateNotification.SerializeToString,
            ),
            'MessageLocationSharingEnd': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageLocationSharingEnd,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingEndNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingEndNotification.SerializeToString,
            ),
            'MessageReactionAdded': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageReactionAdded,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionAddedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionAddedNotification.SerializeToString,
            ),
            'MessageReactionUpdated': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageReactionUpdated,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionUpdatedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionUpdatedNotification.SerializeToString,
            ),
            'MessageReactionRemoved': grpc.unary_stream_rpc_method_handler(
                    servicer.MessageReactionRemoved,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionRemovedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionRemovedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.MessageNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.MessageNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class MessageNotificationService(object):
    """Message
    """

    @staticmethod
    def MessageReceived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageReceived',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReceivedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReceivedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageSent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageSent',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageSentNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageSentNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageDeleted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageDeleted',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeletedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeletedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageBodyUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageBodyUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageBodyUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageBodyUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageUploaded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageUploaded',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageUploadedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageUploadedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageDelivered(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageDelivered',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageDeliveredNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageDeliveredNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageRead(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageRead',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReadNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReadNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageLocationReceived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationReceived',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationReceivedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationReceivedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageLocationSent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSent',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSentNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSentNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageLocationSharingStart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingStart',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingStartNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingStartNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageLocationSharingUpdate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingUpdate',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingUpdateNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingUpdateNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageLocationSharingEnd(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageLocationSharingEnd',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageLocationSharingEndNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageLocationSharingEndNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageReactionAdded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionAdded',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionAddedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionAddedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageReactionUpdated(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionUpdated',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionUpdatedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionUpdatedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def MessageReactionRemoved(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.MessageNotificationService/MessageReactionRemoved',
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.SubscribeToMessageReactionRemovedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_message__notifications__pb2.MessageReactionRemovedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class AttachmentNotificationServiceStub(object):
    """Attachment
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.AttachmentReceived = channel.unary_stream(
                '/olvid.daemon.services.v1.AttachmentNotificationService/AttachmentReceived',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentReceivedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentReceivedNotification.FromString,
                _registered_method=True)
        self.AttachmentUploaded = channel.unary_stream(
                '/olvid.daemon.services.v1.AttachmentNotificationService/AttachmentUploaded',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentUploadedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentUploadedNotification.FromString,
                _registered_method=True)


class AttachmentNotificationServiceServicer(object):
    """Attachment
    """

    def AttachmentReceived(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachmentUploaded(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AttachmentNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'AttachmentReceived': grpc.unary_stream_rpc_method_handler(
                    servicer.AttachmentReceived,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentReceivedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentReceivedNotification.SerializeToString,
            ),
            'AttachmentUploaded': grpc.unary_stream_rpc_method_handler(
                    servicer.AttachmentUploaded,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentUploadedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentUploadedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.AttachmentNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.AttachmentNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AttachmentNotificationService(object):
    """Attachment
    """

    @staticmethod
    def AttachmentReceived(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.AttachmentNotificationService/AttachmentReceived',
            olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentReceivedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentReceivedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AttachmentUploaded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.AttachmentNotificationService/AttachmentUploaded',
            olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.SubscribeToAttachmentUploadedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_attachment__notifications__pb2.AttachmentUploadedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)


class CallNotificationServiceStub(object):
    """Call
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CallIncomingCall = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallIncomingCall',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallIncomingCallNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallIncomingCallNotification.FromString,
                _registered_method=True)
        self.CallRinging = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallRinging',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallRingingNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallRingingNotification.FromString,
                _registered_method=True)
        self.CallAccepted = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallAccepted',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallAcceptedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallAcceptedNotification.FromString,
                _registered_method=True)
        self.CallDeclined = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallDeclined',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallDeclinedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallDeclinedNotification.FromString,
                _registered_method=True)
        self.CallBusy = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallBusy',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallBusyNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallBusyNotification.FromString,
                _registered_method=True)
        self.CallEnded = channel.unary_stream(
                '/olvid.daemon.services.v1.CallNotificationService/CallEnded',
                request_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallEndedNotification.SerializeToString,
                response_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallEndedNotification.FromString,
                _registered_method=True)


class CallNotificationServiceServicer(object):
    """Call
    """

    def CallIncomingCall(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallRinging(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallAccepted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallDeclined(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallBusy(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CallEnded(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CallNotificationServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CallIncomingCall': grpc.unary_stream_rpc_method_handler(
                    servicer.CallIncomingCall,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallIncomingCallNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallIncomingCallNotification.SerializeToString,
            ),
            'CallRinging': grpc.unary_stream_rpc_method_handler(
                    servicer.CallRinging,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallRingingNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallRingingNotification.SerializeToString,
            ),
            'CallAccepted': grpc.unary_stream_rpc_method_handler(
                    servicer.CallAccepted,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallAcceptedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallAcceptedNotification.SerializeToString,
            ),
            'CallDeclined': grpc.unary_stream_rpc_method_handler(
                    servicer.CallDeclined,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallDeclinedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallDeclinedNotification.SerializeToString,
            ),
            'CallBusy': grpc.unary_stream_rpc_method_handler(
                    servicer.CallBusy,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallBusyNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallBusyNotification.SerializeToString,
            ),
            'CallEnded': grpc.unary_stream_rpc_method_handler(
                    servicer.CallEnded,
                    request_deserializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallEndedNotification.FromString,
                    response_serializer=olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallEndedNotification.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'olvid.daemon.services.v1.CallNotificationService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('olvid.daemon.services.v1.CallNotificationService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class CallNotificationService(object):
    """Call
    """

    @staticmethod
    def CallIncomingCall(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallIncomingCall',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallIncomingCallNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallIncomingCallNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CallRinging(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallRinging',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallRingingNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallRingingNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CallAccepted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallAccepted',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallAcceptedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallAcceptedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CallDeclined(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallDeclined',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallDeclinedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallDeclinedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CallBusy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallBusy',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallBusyNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallBusyNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CallEnded(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/olvid.daemon.services.v1.CallNotificationService/CallEnded',
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.SubscribeToCallEndedNotification.SerializeToString,
            olvid_dot_daemon_dot_notification_dot_v1_dot_call__notifications__pb2.CallEndedNotification.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: olvid/daemon/datatypes/v1/keycloak.proto
# Protobuf Python Version: 6.33.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    33,
    2,
    '',
    'olvid/daemon/datatypes/v1/keycloak.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .....olvid.daemon.datatypes.v1 import identity_pb2 as olvid_dot_daemon_dot_datatypes_dot_v1_dot_identity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(olvid/daemon/datatypes/v1/keycloak.proto\x12\x19olvid.daemon.datatypes.v1\x1a(olvid/daemon/datatypes/v1/identity.proto\"\xcb\x01\n\x0cKeycloakUser\x12\x1f\n\x0bkeycloak_id\x18\x01 \x01(\tR\nkeycloakId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12\x44\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsR\x07\x64\x65tails\x12\"\n\ncontact_id\x18\x04 \x01(\x04H\x00R\tcontactId\x88\x01\x01\x42\r\n\x0b_contact_id\"\xf6\x02\n\x12KeycloakUserFilter\x12T\n\x07\x63ontact\x18\x01 \x01(\x0e\x32\x35.olvid.daemon.datatypes.v1.KeycloakUserFilter.ContactH\x00R\x07\x63ontact\x88\x01\x01\x12\x33\n\x13\x64isplay_name_search\x18\x02 \x01(\tH\x01R\x11\x64isplayNameSearch\x88\x01\x01\x12V\n\x0e\x64\x65tails_search\x18\x03 \x01(\x0b\x32*.olvid.daemon.datatypes.v1.IdentityDetailsH\x02R\rdetailsSearch\x88\x01\x01\"F\n\x07\x43ontact\x12\x17\n\x13\x43ONTACT_UNSPECIFIED\x10\x00\x12\x0e\n\nCONTACT_IS\x10\x01\x12\x12\n\x0e\x43ONTACT_IS_NOT\x10\x02\x42\n\n\x08_contactB\x16\n\x14_display_name_searchB\x11\n\x0f_details_search\"\x7f\n\x16KeycloakApiCredentials\x12\x1d\n\nserver_url\x18\x01 \x01(\tR\tserverUrl\x12\x1a\n\x08username\x18\x02 \x01(\tR\x08username\x12*\n\x11\x64irect_auth_token\x18\x03 \x01(\tR\x0f\x64irectAuthTokenB\xc6\x01\n\x1d\x63om.olvid.daemon.datatypes.v1B\rKeycloakProtoP\x01Z\x0folvid.io/daemon\xa2\x02\x03ODD\xaa\x02\x19Olvid.Daemon.Datatypes.V1\xca\x02\x19Olvid\\Daemon\\Datatypes\\V1\xe2\x02%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\xea\x02\x1cOlvid::Daemon::Datatypes::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'olvid.daemon.datatypes.v1.keycloak_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035com.olvid.daemon.datatypes.v1B\rKeycloakProtoP\001Z\017olvid.io/daemon\242\002\003ODD\252\002\031Olvid.Daemon.Datatypes.V1\312\002\031Olvid\\Daemon\\Datatypes\\V1\342\002%Olvid\\Daemon\\Datatypes\\V1\\GPBMetadata\352\002\034Olvid::Daemon::Datatypes::V1'
  _globals['_KEYCLOAKUSER']._serialized_start=114
  _globals['_KEYCLOAKUSER']._serialized_end=317
  _globals['_KEYCLOAKUSERFILTER']._serialized_start=320
  _globals['_KEYCLOAKUSERFILTER']._serialized_end=694
  _globals['_KEYCLOAKUSERFILTER_CONTACT']._serialized_start=569
  _globals['_KEYCLOAKUSERFILTER_CONTACT']._serialized_end=639
  _globals['_KEYCLOAKAPICREDENTIALS']._serialized_start=696
  _globals['_KEYCLOAKAPICREDENTIALS']._serialized_end=823
# @@protoc_insertion_point(module_scope)
